@@ -19,7 +19,7 @@ import validators
 from urllib.parse import urljoin
 from urllib.parse import urlsplit
 import aiohttp
-from aiohttp import ClientSession
+from aiohttp import ClientSession,ClientTimeout
 import async_timeout
 
 
@@ -144,13 +144,18 @@ async def tcp_echo_clientviper(message, loop,host,port,microserviceid,timeout=60
 
     geturl=formaturlviper(message,host,microserviceid,hbuf,port) #host contains http:// or https://
     message="%s" % geturl
-             
+    stimeout = ClientTimeout(total=timeout)
+     
     try:
      with async_timeout.timeout(timeout):
-      async with ClientSession(connector = aiohttp.TCPConnector(ssl=False)) as session:
-        html = await fetch2(session,message)
-        await session.close()
-        return html
+      async with ClientSession(connector = aiohttp.TCPConnector(ssl=False),timeout=stimeout) as session:
+        try:
+          html = await fetch2(session,message)
+          await session.close()
+          return html
+        except Exception as e:
+          print(e)
+          pass
     except (aiohttp.ServerDisconnectedError, aiohttp.ClientResponseError,aiohttp.ClientConnectorError) as e:       
      connectionerror=str(e)   
      print("TCPConnectionError=",e)   
@@ -227,11 +232,11 @@ def vipermirrorbrokers(vipertoken,host,port,brokercloudusernamepassfrom,brokercl
 
 
     if (len(host)==0 or len(vipertoken)==0 or len(brokercloudusernamepassfrom)==0 or len(brokercloudusernamepassto)==0
-         or len(enabletlsfrom)==0 or len(enabletlsto)==0 or len(replicationfactorfrom)==0 or len(replicationfactorto)==0
+         or len(enabletlsfrom)==0 or len(enabletlsto)==0 
          or len(compressionfrom)==0 or len(compressionto)==0 or len(saslfrom)==0 or len(saslto)==0
          or len(brokerlistfrom)==0 or  len(brokerlistto)==0 ):
           return ("Please enter host,port,vipertoken,brokercloudusernamepassfrom, brokercloudusernamepassto, enabletlsfrom,\
-enabletlsto,replicationfactorfrom,replicationfactorto,compressionfrom,compressionto,saslfrom,saslto,brokerlistfrom,brokerlistto")
+enabletlsto,compressionfrom,compressionto,saslfrom,saslto,brokerlistfrom,brokerlistto")
     
     value=("writestreamtobrokers?vipertoken="+vipertoken + "&enabletlsfrom="+enabletlsfrom + "&enabletlsto=" + enabletlsto
            + "&replicationfactorfrom=" + replicationfactorfrom + "&replicationfactorto=" + replicationfactorto
